@@ -18,7 +18,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: util.c,v 1.129 2003/04/28 12:07:37 michael Exp $
+    $Id: util.c,v 1.130 2003/06/12 12:59:36 fherrera Exp $
 
 ***************************************************************************/
 #include <assert.h>
@@ -328,6 +328,10 @@ int IDL_parse_filename (const char *filename, const char *cpp_args,
 		    cwd, cpp_args ? cpp_args : "", tmpfilename, cpperrs);
 #endif
 
+       /* Many versions of cpp do evil translating internal
+        * strings, producing bogus output, so clobber LC_ALL */
+       putenv ("LC_ALL=C");
+
 #ifdef HAVE_POPEN
 	input = popen (cmd, "r");
 #else
